==> kpilot-trinity-3.5.13.2.tar.xz: kpilot-trinity-3.5.13.2/kpilot/fileInstallWidget.h <==
#ifndef _KPILOT_FILEINSTALLWIDGET_H
#define _KPILOT_FILEINSTALLWIDGET_H
/* fileInstallWidget.h			KPilot
**
** Copyright (C) 1998-2001 by Dan Pilone
**
** This file defines the file install widget, which is the thing
** that accepts file drags for later installation into the Pilot.
**
** This file also defines the log window widget, which logs
** sync-messages during a HotSync.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
** MA 02110-1301, USA.
*/

/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include "pilotComponent.h"

class TQMultiLineEdit;
class TQPushButton;
class TQIconDragItem;

class KIconView;
class KPilotInstaller;
class FileInstaller;

class FileInstallWidget : public PilotComponent
{
Q_OBJECT
  TQ_OBJECT

public:
	FileInstallWidget(TQWidget* parent, const TQString& dbPath);
	virtual ~FileInstallWidget();

	// Pilot Component Methods:
	void showComponent();
	bool preHotSync(TQString &);
	void postHotSync();


signals:
	void fileInstallWidgetDone();

protected:
	void setSaveFileList(bool saveIt) { fSaveFileList = saveIt; }
	bool getSaveFileList() { return fSaveFileList; }

	/* virtual */ void dragEnterEvent(TQDragEnterEvent* event);
	/* virtual */ void dropEvent(TQDropEvent* drop);
	/* virtual */ bool eventFilter (TQObject *watched, TQEvent *event );

    void contextMenu(TQMouseEvent *event);

	KPilotInstaller* getPilotInstallerApp() { return fKPilotInstaller; }

private:
	KIconView  *fIconView;
	bool        fSaveFileList;

	KPilotInstaller* fKPilotInstaller;
	FileInstaller *fInstaller;
	TQPushButton *clearButton,*addButton;

protected slots:
	void slotClearButton();
	void slotAddFile();

	void slotDropEvent(TQDropEvent * drop, const TQValueList<TQIconDragItem> & lst);

public slots:
	void refreshFileInstallList();
};

#endif

==> kpilot-trinity-14.0.12.tar.xz: kpilot-trinity-14.0.12/kpilot/fileInstallWidget.h <==
#ifndef _KPILOT_FILEINSTALLWIDGET_H
#define _KPILOT_FILEINSTALLWIDGET_H
/* fileInstallWidget.h			KPilot
**
** Copyright (C) 1998-2001 by Dan Pilone
**
** This file defines the file install widget, which is the thing
** that accepts file drags for later installation into the Pilot.
**
** This file also defines the log window widget, which logs
** sync-messages during a HotSync.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
** MA 02110-1301, USA.
*/

/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include "pilotComponent.h"

class TQMultiLineEdit;
class TQPushButton;
class TQIconDragItem;

class TDEIconView;
class KPilotInstaller;
class FileInstaller;

class FileInstallWidget : public PilotComponent
{
Q_OBJECT
  

public:
	FileInstallWidget(TQWidget* parent, const TQString& dbPath);
	virtual ~FileInstallWidget();

	// Pilot Component Methods:
	void showComponent();
	bool preHotSync(TQString &);
	void postHotSync();


signals:
	void fileInstallWidgetDone();

protected:
	void setSaveFileList(bool saveIt) { fSaveFileList = saveIt; }
	bool getSaveFileList() { return fSaveFileList; }

	/* virtual */ void dragEnterEvent(TQDragEnterEvent* event);
	/* virtual */ void dropEvent(TQDropEvent* drop);
	/* virtual */ bool eventFilter (TQObject *watched, TQEvent *event );

    void contextMenu(TQMouseEvent *event);

	KPilotInstaller* getPilotInstallerApp() { return fKPilotInstaller; }

private:
	TDEIconView  *fIconView;
	bool        fSaveFileList;

	KPilotInstaller* fKPilotInstaller;
	FileInstaller *fInstaller;
	TQPushButton *clearButton,*addButton;

protected slots:
	void slotClearButton();
	void slotAddFile();

	void slotDropEvent(TQDropEvent * drop, const TQValueList<TQIconDragItem> & lst);

public slots:
	void refreshFileInstallList();
};

#endif
